"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeBundles = exports.createBundles = exports.rollupWatch = exports.createRollupConfig = void 0;
var tslib_1 = require("tslib");
var path_1 = require("path");
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var rollup_1 = require("rollup");
var plugin_node_resolve_1 = tslib_1.__importDefault(require("@rollup/plugin-node-resolve"));
var plugin_commonjs_1 = tslib_1.__importDefault(require("@rollup/plugin-commonjs"));
var plugin_json_1 = tslib_1.__importDefault(require("@rollup/plugin-json"));
var plugin_replace_1 = tslib_1.__importDefault(require("@rollup/plugin-replace"));
var rollup_plugin_typescript2_1 = tslib_1.__importDefault(require("rollup-plugin-typescript2"));
var rollup_plugin_sourcemaps_1 = tslib_1.__importDefault(require("rollup-plugin-sourcemaps"));
var rollup_plugin_terser_1 = require("rollup-plugin-terser");
var utils_1 = require("../utils/utils");
var error_1 = require("../utils/error");
var createRollupConfig = function (_a) {
    var tsconfigPath = _a.tsconfigPath, addUmdBuild = _a.addUmdBuild, kebabCasePkgName = _a.kebabCasePkgName, pkgJsonSideEffects = _a.pkgJsonSideEffects, pkgJsonPeerDependencyKeys = _a.pkgJsonPeerDependencyKeys, pkgJsonUmdGlobalDependencies = _a.pkgJsonUmdGlobalDependencies;
    // 默认配置
    var buildPluginsDefault = [
        plugin_node_resolve_1.default({ preferBuiltins: true }),
        plugin_commonjs_1.default(),
        plugin_json_1.default(),
        rollup_plugin_typescript2_1.default({
            tsconfigDefaults: {
                compilerOptions: {
                    target: 'ES2018',
                    types: [],
                    declaration: true,
                    rootDir: './src',
                },
                include: ['src', './node_modules/rollpkg/configs/types'],
                exclude: [
                    '**/__tests__',
                    '**/__mocks__',
                    '**/__snapshots__',
                    '**/*.test.*',
                    '**/*.spec.*',
                    '**/*.mock.*',
                ],
            },
            tsconfig: tsconfigPath,
            tsconfigOverride: {
                compilerOptions: {
                    module: 'ESNext',
                    sourceMap: true,
                },
            },
            include: ['**/*.ts+(|x)', '**/*.js+(|x)'],
        }),
        rollup_plugin_sourcemaps_1.default(),
        plugin_replace_1.default({
            __DEV__: "process.env.NODE_ENV !== 'production'",
            preventAssignment: true,
        }),
    ];
    // 开发配置
    var buildPluginsWithNodeEnvDevelopment = tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(buildPluginsDefault)), [
        plugin_replace_1.default({
            'process.env.NODE_ENV': JSON.stringify('development'),
            preventAssignment: true,
        }),
    ]);
    // 生产配置
    var buildPluginsWithNodeEnvProduction = tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(buildPluginsDefault)), [
        plugin_replace_1.default({
            'process.env.NODE_ENV': JSON.stringify('production'),
            preventAssignment: true,
        }),
    ]);
    var outputPluginsDefault = [];
    var outputPluginsProduction = [
        rollup_plugin_terser_1.terser({ format: { comments: false } }),
    ];
    var treeshakeOptions = {
        annotations: true,
        moduleSideEffects: pkgJsonSideEffects,
        propertyReadSideEffects: pkgJsonSideEffects,
        tryCatchDeoptimization: pkgJsonSideEffects,
        unknownGlobalSideEffects: pkgJsonSideEffects,
    };
    var umdExternalDependencies;
    var umdDependencyGlobals;
    var umdNameForPkg;
    if (addUmdBuild) {
        umdExternalDependencies = pkgJsonUmdGlobalDependencies
            ? Object.keys(pkgJsonUmdGlobalDependencies)
            : pkgJsonPeerDependencyKeys;
        if (pkgJsonUmdGlobalDependencies) {
            umdDependencyGlobals = pkgJsonUmdGlobalDependencies;
        }
        else {
            pkgJsonPeerDependencyKeys.forEach(function (peerDep) {
                umdDependencyGlobals = {};
                umdDependencyGlobals[peerDep] = utils_1.convertKebabCaseToPascalCase(utils_1.convertPkgNameToKebabCase(peerDep));
            });
        }
        umdNameForPkg = utils_1.convertKebabCaseToPascalCase(kebabCasePkgName);
    }
    return {
        buildPluginsDefault: buildPluginsDefault,
        buildPluginsWithNodeEnvDevelopment: buildPluginsWithNodeEnvDevelopment,
        buildPluginsWithNodeEnvProduction: buildPluginsWithNodeEnvProduction,
        outputPluginsDefault: outputPluginsDefault,
        outputPluginsProduction: outputPluginsProduction,
        treeshakeOptions: treeshakeOptions,
        umdNameForPkg: umdNameForPkg,
        umdExternalDependencies: umdExternalDependencies,
        umdDependencyGlobals: umdDependencyGlobals,
    };
};
exports.createRollupConfig = createRollupConfig;
var rollupWatch = function (_a) {
    var kebabCasePkgName = _a.kebabCasePkgName, pkgJsonDependencyKeys = _a.pkgJsonDependencyKeys, pkgJsonPeerDependencyKeys = _a.pkgJsonPeerDependencyKeys, entryFile = _a.entryFile, treeshakeOptions = _a.treeshakeOptions, buildPluginsDefault = _a.buildPluginsDefault, outputPluginsDefault = _a.outputPluginsDefault;
    var exitWatch = function () {
        utils_1.clearLine();
        console.log('WATCH END 👀👋', '\n');
        process.exit(0);
    };
    process.on('SIGINT', exitWatch);
    process.on('SIGTERM', exitWatch);
    process.on('SIGBREAK', exitWatch);
    var esmWatchOptions = {
        external: tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(pkgJsonDependencyKeys)), tslib_1.__read(pkgJsonPeerDependencyKeys)),
        input: entryFile,
        treeshake: treeshakeOptions,
        plugins: buildPluginsDefault,
        output: {
            file: "dist/" + kebabCasePkgName + ".esm.js",
            format: 'esm',
            sourcemap: true,
            plugins: outputPluginsDefault,
        },
    };
    var watcher = rollup_1.watch(esmWatchOptions);
    var earth = ['⚽️', '⚽️', '⚽️'];
    var currentEarth = 2;
    var rotateEarth = function () {
        if (currentEarth === 2)
            currentEarth = 0;
        else {
            currentEarth = currentEarth + 1;
        }
        return earth[currentEarth];
    };
    watcher.on('event', function (event) {
        switch (event.code) {
            case 'START':
                break;
            case 'BUNDLE_START':
                utils_1.clearConsole();
                console.log(rotateEarth() + " \u5F00\u59CB\u6253\u5305...", '\n');
                break;
            case 'BUNDLE_END':
                utils_1.clearConsole();
                console.log(earth[currentEarth] + " \u6253\u5305\u6210\u529F!", '\n');
                console.log('Watching for changes...', '\n');
                break;
            case 'END':
                break;
            case 'ERROR':
                utils_1.clearConsole();
                if (event.error.plugin === 'rpt2') {
                    error_1.logTsError({ message: event.error.message });
                }
                else {
                    error_1.logError({ fullError: event.error });
                }
                console.log('Watching for changes...', '\n');
                break;
        }
    });
};
exports.rollupWatch = rollupWatch;
var createBundles = function (_a) {
    var entryFile = _a.entryFile, pkgJsonDependencyKeys = _a.pkgJsonDependencyKeys, pkgJsonPeerDependencyKeys = _a.pkgJsonPeerDependencyKeys, umdExternalDependencies = _a.umdExternalDependencies, treeshakeOptions = _a.treeshakeOptions, buildPluginsDefault = _a.buildPluginsDefault, buildPluginsWithNodeEnvDevelopment = _a.buildPluginsWithNodeEnvDevelopment, buildPluginsWithNodeEnvProduction = _a.buildPluginsWithNodeEnvProduction, addUmdBuild = _a.addUmdBuild;
    return Promise.all([
        // default bundle - used for esm and cjs dev builds
        rollup_1.rollup({
            external: tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(pkgJsonDependencyKeys)), tslib_1.__read(pkgJsonPeerDependencyKeys)),
            input: entryFile,
            treeshake: treeshakeOptions,
            plugins: buildPluginsDefault,
        }),
        // cjs production build
        rollup_1.rollup({
            external: tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(pkgJsonDependencyKeys)), tslib_1.__read(pkgJsonPeerDependencyKeys)),
            input: entryFile,
            treeshake: treeshakeOptions,
            plugins: buildPluginsWithNodeEnvProduction,
        }),
        // umd development build
        addUmdBuild
            ? rollup_1.rollup({
                external: umdExternalDependencies,
                input: entryFile,
                treeshake: treeshakeOptions,
                plugins: buildPluginsWithNodeEnvDevelopment,
            })
            : undefined,
        // umd production build
        addUmdBuild
            ? rollup_1.rollup({
                external: umdExternalDependencies,
                input: entryFile,
                treeshake: treeshakeOptions,
                plugins: buildPluginsWithNodeEnvProduction,
            })
            : undefined,
    ]);
};
exports.createBundles = createBundles;
var writeBundles = function (_a) {
    var cwd = _a.cwd, kebabCasePkgName = _a.kebabCasePkgName, bundleDefault = _a.bundleDefault, bundleCjsProd = _a.bundleCjsProd, bundleUmdDev = _a.bundleUmdDev, bundleUmdProd = _a.bundleUmdProd, outputPluginsDefault = _a.outputPluginsDefault, outputPluginsProduction = _a.outputPluginsProduction, umdNameForPkg = _a.umdNameForPkg, umdDependencyGlobals = _a.umdDependencyGlobals;
    var cjsEntryContent = "'use strict';\n\nif (process.env.NODE_ENV === 'production') {\n  module.exports = require('./" + kebabCasePkgName + ".cjs.production.js');\n} else {\n  module.exports = require('./" + kebabCasePkgName + ".cjs.development.js');\n}\n";
    return Promise.all([
        // esm build
        bundleDefault.write({
            file: "dist/" + kebabCasePkgName + ".esm.js",
            format: 'esm',
            sourcemap: true,
            sourcemapExcludeSources: false,
            plugins: outputPluginsDefault,
        }),
        // cjs development build
        bundleDefault.write({
            file: "dist/" + kebabCasePkgName + ".cjs.development.js",
            format: 'cjs',
            sourcemap: true,
            sourcemapExcludeSources: false,
            plugins: outputPluginsDefault,
        }),
        // cjs production build
        bundleCjsProd.write({
            file: "dist/" + kebabCasePkgName + ".cjs.production.js",
            format: 'cjs',
            sourcemap: true,
            sourcemapExcludeSources: false,
            plugins: outputPluginsProduction,
        }),
        // cjs entry file
        fs_extra_1.default.writeFile(path_1.resolve(cwd, 'dist', kebabCasePkgName + ".cjs.js"), cjsEntryContent, 'utf8'),
        bundleUmdDev
            ? bundleUmdDev.write({
                file: "dist/" + kebabCasePkgName + ".umd.development.js",
                format: 'umd',
                name: umdNameForPkg,
                globals: umdDependencyGlobals,
                sourcemap: true,
                sourcemapExcludeSources: false,
                plugins: outputPluginsDefault,
            })
            : undefined,
        bundleUmdProd
            ? bundleUmdProd.write({
                file: "dist/" + kebabCasePkgName + ".umd.production.js",
                format: 'umd',
                name: umdNameForPkg,
                globals: umdDependencyGlobals,
                sourcemap: true,
                sourcemapExcludeSources: false,
                plugins: outputPluginsProduction,
            })
            : undefined,
    ]);
};
exports.writeBundles = writeBundles;
//# sourceMappingURL=index.js.map