"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var error_1 = require("./utils/error");
var utils_1 = require("./utils/utils");
var config_1 = require("./config");
var mooliRollup = function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var cleanDistMessage, clean, error_2, args, cwd, rollpkgConfiguration, _a, watchMode, tsconfigPath, addUmdBuild, entryFile, kebabCasePkgName, pkgJsonSideEffects, pkgJsonDependencyKeys, pkgJsonPeerDependencyKeys, pkgJsonUmdGlobalDependencies, rollupConfiguration, buildPluginsDefault, buildPluginsWithNodeEnvDevelopment, buildPluginsWithNodeEnvProduction, outputPluginsDefault, outputPluginsProduction, treeshakeOptions, umdNameForPkg, umdExternalDependencies, umdDependencyGlobals, createRollupBundlesMessage, bundles, error_3, errorAsObject, _b, bundleDefault, bundleCjsProd, bundleUmdDev, bundleUmdProd, writeRollupBundlesMessage, output, error_4;
    return tslib_1.__generator(this, function (_c) {
        switch (_c.label) {
            case 0:
                cleanDistMessage = 'Cleaning dist folder';
                _c.label = 1;
            case 1:
                _c.trys.push([1, 3, , 4]);
                clean = utils_1.cleanDist();
                return [4 /*yield*/, utils_1.progressEstimator(clean, cleanDistMessage)];
            case 2:
                _c.sent();
                return [3 /*break*/, 4];
            case 3:
                error_2 = _c.sent();
                error_1.logError({
                    failedAt: cleanDistMessage,
                    message: error_1.errorAsObjectWithMessage(error_2).message,
                    fullError: error_2,
                });
                throw error_1.EXIT_ON_ERROR;
            case 4:
                args = process.argv.slice(2);
                cwd = process.cwd();
                try {
                    rollpkgConfiguration = utils_1.checkInvariantsAndGetConfiguration({ args: args, cwd: cwd });
                }
                catch (error) {
                    throw error_1.EXIT_ON_ERROR;
                }
                return [4 /*yield*/, rollpkgConfiguration];
            case 5:
                _a = _c.sent(), watchMode = _a.watchMode, tsconfigPath = _a.tsconfigPath, addUmdBuild = _a.addUmdBuild, entryFile = _a.entryFile, kebabCasePkgName = _a.kebabCasePkgName, pkgJsonSideEffects = _a.pkgJsonSideEffects, pkgJsonDependencyKeys = _a.pkgJsonDependencyKeys, pkgJsonPeerDependencyKeys = _a.pkgJsonPeerDependencyKeys, pkgJsonUmdGlobalDependencies = _a.pkgJsonUmdGlobalDependencies;
                try {
                    rollupConfiguration = config_1.createRollupConfig({
                        tsconfigPath: tsconfigPath,
                        addUmdBuild: addUmdBuild,
                        kebabCasePkgName: kebabCasePkgName,
                        pkgJsonSideEffects: pkgJsonSideEffects,
                        pkgJsonPeerDependencyKeys: pkgJsonPeerDependencyKeys,
                        pkgJsonUmdGlobalDependencies: pkgJsonUmdGlobalDependencies,
                    });
                }
                catch (error) {
                    throw error_1.EXIT_ON_ERROR;
                }
                buildPluginsDefault = rollupConfiguration.buildPluginsDefault, buildPluginsWithNodeEnvDevelopment = rollupConfiguration.buildPluginsWithNodeEnvDevelopment, buildPluginsWithNodeEnvProduction = rollupConfiguration.buildPluginsWithNodeEnvProduction, outputPluginsDefault = rollupConfiguration.outputPluginsDefault, outputPluginsProduction = rollupConfiguration.outputPluginsProduction, treeshakeOptions = rollupConfiguration.treeshakeOptions, umdNameForPkg = rollupConfiguration.umdNameForPkg, umdExternalDependencies = rollupConfiguration.umdExternalDependencies, umdDependencyGlobals = rollupConfiguration.umdDependencyGlobals;
                // rollup watch
                if (watchMode) {
                    config_1.rollupWatch({
                        kebabCasePkgName: kebabCasePkgName,
                        pkgJsonDependencyKeys: pkgJsonDependencyKeys,
                        pkgJsonPeerDependencyKeys: pkgJsonPeerDependencyKeys,
                        entryFile: entryFile,
                        treeshakeOptions: treeshakeOptions,
                        buildPluginsDefault: buildPluginsDefault,
                        outputPluginsDefault: outputPluginsDefault,
                    });
                    return [2 /*return*/];
                }
                createRollupBundlesMessage = "Creating esm, cjs" + (addUmdBuild ? ', umd' : '') + " builds";
                _c.label = 6;
            case 6:
                _c.trys.push([6, 8, , 9]);
                bundles = config_1.createBundles({
                    entryFile: entryFile,
                    pkgJsonDependencyKeys: pkgJsonDependencyKeys,
                    pkgJsonPeerDependencyKeys: pkgJsonPeerDependencyKeys,
                    umdExternalDependencies: umdExternalDependencies,
                    treeshakeOptions: treeshakeOptions,
                    buildPluginsDefault: buildPluginsDefault,
                    buildPluginsWithNodeEnvDevelopment: buildPluginsWithNodeEnvDevelopment,
                    buildPluginsWithNodeEnvProduction: buildPluginsWithNodeEnvProduction,
                    addUmdBuild: addUmdBuild,
                });
                return [4 /*yield*/, utils_1.progressEstimator(bundles, createRollupBundlesMessage, {
                        id: kebabCasePkgName + "-" + createRollupBundlesMessage,
                    })];
            case 7:
                _c.sent();
                return [3 /*break*/, 9];
            case 8:
                error_3 = _c.sent();
                errorAsObject = error_1.errorAsObjectWithMessage(error_3);
                if (errorAsObject.plugin === 'rpt2') {
                    error_1.logTsError({
                        failedAt: createRollupBundlesMessage,
                        message: errorAsObject.message,
                    });
                }
                else {
                    error_1.logError({
                        failedAt: createRollupBundlesMessage,
                        message: errorAsObject.message,
                        fullError: error_3,
                    });
                }
                throw error_1.EXIT_ON_ERROR;
            case 9: return [4 /*yield*/, bundles];
            case 10:
                _b = tslib_1.__read.apply(void 0, [_c.sent(), 4]), bundleDefault = _b[0], bundleCjsProd = _b[1], bundleUmdDev = _b[2], bundleUmdProd = _b[3];
                writeRollupBundlesMessage = "Writing esm, cjs" + (addUmdBuild ? ', umd' : '') + " builds";
                _c.label = 11;
            case 11:
                _c.trys.push([11, 13, , 14]);
                output = config_1.writeBundles({
                    cwd: cwd,
                    kebabCasePkgName: kebabCasePkgName,
                    bundleDefault: bundleDefault,
                    bundleCjsProd: bundleCjsProd,
                    bundleUmdDev: bundleUmdDev,
                    bundleUmdProd: bundleUmdProd,
                    outputPluginsDefault: outputPluginsDefault,
                    outputPluginsProduction: outputPluginsProduction,
                    umdNameForPkg: umdNameForPkg,
                    umdDependencyGlobals: umdDependencyGlobals,
                });
                return [4 /*yield*/, utils_1.progressEstimator(output, writeRollupBundlesMessage, {
                        id: kebabCasePkgName + "-" + writeRollupBundlesMessage,
                    })];
            case 12:
                _c.sent();
                return [3 /*break*/, 14];
            case 13:
                error_4 = _c.sent();
                error_1.logError({
                    failedAt: writeRollupBundlesMessage,
                    message: error_1.errorAsObjectWithMessage(error_4).message,
                    fullError: error_4,
                });
                throw error_1.EXIT_ON_ERROR;
            case 14: 
            // build success
            return [4 /*yield*/, utils_1.progressEstimator(Promise.resolve(), 'BUILD SUCCESS 😁😘')];
            case 15:
                // build success
                _c.sent();
                return [2 /*return*/];
        }
    });
}); };
var errorExitCode = process.argv[2] === 'watch' ? 0 : 1;
mooliRollup().catch(function (error) {
    if (error === error_1.EXIT_ON_ERROR) {
        utils_1.cleanDist()
            .catch()
            .finally(function () {
            process.exit(errorExitCode);
        });
    }
    else {
        error_1.logError({ message: 'UNKNOWN ERROR', fullError: error });
        process.exit(errorExitCode);
    }
});
//# sourceMappingURL=index.js.map