"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkInvariantsAndGetConfiguration = exports.fileExists = exports.convertKebabCaseToPascalCase = exports.convertPkgNameToKebabCase = exports.progressEstimator = exports.getCacheDir = exports.clearConsole = exports.clearLine = exports.cleanDist = void 0;
var tslib_1 = require("tslib");
var os_1 = tslib_1.__importDefault(require("os"));
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var path_1 = require("path");
var readline_1 = tslib_1.__importDefault(require("readline"));
var find_cache_dir_1 = tslib_1.__importDefault(require("find-cache-dir"));
var progress_estimator_1 = tslib_1.__importDefault(require("progress-estimator"));
var cleanDist = function () { return fs_extra_1.default.emptyDir('./dist'); };
exports.cleanDist = cleanDist;
var clearLine = function () {
    readline_1.default.clearLine(process.stdout, 0);
    readline_1.default.cursorTo(process.stdout, 0);
};
exports.clearLine = clearLine;
var clearConsole = function () {
    process.stdout.write(process.platform === 'win32' ? '\x1B[2J\x1B[0f' : '\x1B[2J\x1B[3J\x1B[H');
};
exports.clearConsole = clearConsole;
var getCacheDir = function () {
    var pathParts = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        pathParts[_i] = arguments[_i];
    }
    var thunk = find_cache_dir_1.default({ name: 'mooli-rollup', create: true, thunk: true });
    // @ts-ignore
    return thunk ? thunk.apply(void 0, tslib_1.__spreadArray([], tslib_1.__read(pathParts))) : path_1.resolve.apply(void 0, tslib_1.__spreadArray([os_1.default.tmpdir()], tslib_1.__read(pathParts)));
};
exports.getCacheDir = getCacheDir;
exports.progressEstimator = progress_estimator_1.default({
    storagePath: exports.getCacheDir('progress-estimator'),
    spinner: {
        interval: 180,
        frames: ['⚽️', '⚽️', '⚽️'],
    },
});
var convertPkgNameToKebabCase = function (pkgName) {
    return pkgName.replace(/[@!]/g, '').replace(/\//g, '-');
};
exports.convertPkgNameToKebabCase = convertPkgNameToKebabCase;
var convertKebabCaseToPascalCase = function (kebabCase) {
    return kebabCase
        .split('-')
        .map(function (s) { return "" + s[0].toUpperCase() + s.slice(1); })
        .join('');
};
exports.convertKebabCaseToPascalCase = convertKebabCaseToPascalCase;
var fileExists = function (dirPath, fileName) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var stats, _a;
    return tslib_1.__generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _b.trys.push([0, 2, , 3]);
                return [4 /*yield*/, fs_extra_1.default.stat(path_1.resolve(dirPath, fileName))];
            case 1:
                stats = _b.sent();
                return [2 /*return*/, stats.isFile()];
            case 2:
                _a = _b.sent();
                return [2 /*return*/, false];
            case 3: return [2 /*return*/];
        }
    });
}); };
exports.fileExists = fileExists;
var checkInvariantsAndGetConfiguration = function (_a) {
    var args = _a.args, cwd = _a.cwd;
    return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var srcDir, indexTsExists, watchMode, tsconfigPath, tsconfigOptionIdx, e_1, pkgJson, readPkgJson, _b, pkgJsonName, addUmdBuild, entryFile, kebabCasePkgName, pkgJsonSideEffects, pkgJsonDependencyKeys, pkgJsonPeerDependencyKeys, pkgJsonUmdGlobalDependencies;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    srcDir = path_1.resolve(cwd, 'src');
                    return [4 /*yield*/, exports.fileExists(srcDir, 'index.ts')];
                case 1:
                    indexTsExists = _c.sent();
                    watchMode = args[0] === 'watch';
                    tsconfigOptionIdx = args.indexOf('--tsconfig');
                    if (!(tsconfigOptionIdx !== -1)) return [3 /*break*/, 5];
                    tsconfigPath = args[tsconfigOptionIdx + 1];
                    _c.label = 2;
                case 2:
                    _c.trys.push([2, 4, , 5]);
                    return [4 /*yield*/, fs_extra_1.default.readFile(tsconfigPath, 'utf8')];
                case 3:
                    _c.sent();
                    return [3 /*break*/, 5];
                case 4:
                    e_1 = _c.sent();
                    throw new Error("Cannot read tsconfig at " + tsconfigPath);
                case 5:
                    _c.trys.push([5, 7, , 8]);
                    return [4 /*yield*/, fs_extra_1.default.readFile(path_1.resolve(cwd, 'package.json'), 'utf8')];
                case 6:
                    readPkgJson = _c.sent();
                    pkgJson = JSON.parse(readPkgJson);
                    return [3 /*break*/, 8];
                case 7:
                    _b = _c.sent();
                    throw Error("Cannot read package.json at " + path_1.resolve(cwd, 'package.json'));
                case 8:
                    pkgJsonName = pkgJson.name;
                    addUmdBuild = args.includes('--addUmdBuild');
                    entryFile = path_1.resolve(srcDir, indexTsExists ? 'index.ts' : 'index.tsx');
                    kebabCasePkgName = exports.convertPkgNameToKebabCase(pkgJsonName);
                    pkgJsonSideEffects = pkgJson.sideEffects;
                    pkgJsonDependencyKeys = pkgJson.dependencies
                        ? Object.keys(pkgJson.dependencies)
                        : [];
                    pkgJsonPeerDependencyKeys = pkgJson.peerDependencies
                        ? Object.keys(pkgJson.peerDependencies)
                        : [];
                    pkgJsonUmdGlobalDependencies = pkgJson.umdGlobalDependencies;
                    return [2 /*return*/, {
                            watchMode: watchMode,
                            tsconfigPath: tsconfigPath,
                            addUmdBuild: addUmdBuild,
                            entryFile: entryFile,
                            kebabCasePkgName: kebabCasePkgName,
                            pkgJsonSideEffects: pkgJsonSideEffects,
                            pkgJsonDependencyKeys: pkgJsonDependencyKeys,
                            pkgJsonPeerDependencyKeys: pkgJsonPeerDependencyKeys,
                            pkgJsonUmdGlobalDependencies: pkgJsonUmdGlobalDependencies
                        }];
            }
        });
    });
};
exports.checkInvariantsAndGetConfiguration = checkInvariantsAndGetConfiguration;
//# sourceMappingURL=utils.js.map